@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['da'] = {
     "Strikethrough": "Gennemstreg",
     "Font Size": "Skriftst\u00f8rrelse",
     "Color": "Farve",
-    "Background Color": "Baggrunds farve",
-    "Text Color": "Tekst farve",
+    "Background": "Baggrunds",
+    "Text": "Tekst",
     "Format Block": "Formater",
     "Normal": "Normal",
     "Paragraph": "S\u00e6tning",
@@ -51,7 +51,6 @@ $.Editable.LANGS['da'] = {
     "Replace Image": "Udskift billedet",
     "Remove Image": "Fjern billede",
     "Title": "Titel",
-    "Insert image": "Inds\u00e6t billede",
     "Drop image": "Dr\u00e5be billede",
     "or click": "eller klik p\u00e5",
     "or": "eller",
