@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['hu'] = {
     "Strikethrough": "\u00c1th\u00fazott",
     "Font Size": "Bet\u0171m\u00e9retek",
     "Color": "Sz\u00edne",
-    "Background Color": "H\u00e1tt\u00e9r sz\u00edn",
-    "Text Color": "Sz\u00f6veg sz\u00edne",
+    "Background": "H\u00e1tt\u00e9r",
+    "Text": "Sz\u00f6veg",
     "Format Block": "Form\u00e1tumok",
     "Normal": "Norm\u00e1l",
     "Paragraph": "Bekezd\u00e9s",
@@ -51,7 +51,6 @@ $.Editable.LANGS['hu'] = {
     "Replace Image": "K\u00e9pek cser\u00e9je",
     "Remove Image": "K\u00e9p elt\u00e1vol\u00edt\u00e1sa",
     "Title": "C\u00edm",
-    "Insert image": "K\u00e9p besz\u00far\u00e1sa",
     "Drop image": "Dobd k\u00e9p",
     "or click": "vagy kattintson",
     "or": "vagy",
