@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.2.1 (http://editor.froala.com)
+ * froala_editor v1.2.3 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -15,8 +15,8 @@ $.Editable.LANGS['th'] = {
     "Strikethrough": "\u0e02\u0e35\u0e14\u0e17\u0e31\u0e1a",
     "Font Size": "\u0e02\u0e19\u0e32\u0e14\u0e41\u0e1a\u0e1a\u0e2d\u0e31\u0e01\u0e29\u0e23",
     "Color": "\u0e2a\u0e35",
-    "Background Color": "\u0e2a\u0e35\u0e1e\u0e37\u0e49\u0e19\u0e2b\u0e25\u0e31\u0e07",
-    "Text Color": "\u0e2a\u0e35\u0e02\u0e49\u0e2d\u0e04\u0e27\u0e32\u0e21",
+    "Background": "\u0e1e\u0e37\u0e49\u0e19\u0e2b\u0e25\u0e31\u0e07",
+    "Text": "\u0e02\u0e49\u0e2d\u0e04\u0e27\u0e32\u0e21",
     "Format Block": "\u0e23\u0e39\u0e1b\u0e41\u0e1a\u0e1a",
     "Normal": "\u0e1b\u0e01\u0e15\u0e34",
     "Paragraph": "\u0e22\u0e48\u0e2d\u0e2b\u0e19\u0e49\u0e32",
@@ -51,7 +51,6 @@ $.Editable.LANGS['th'] = {
     "Replace Image": "\u0e41\u0e17\u0e19\u0e17\u0e35\u0e48\u0e20\u0e32\u0e1e",
     "Remove Image": "\u0e25\u0e1a\u0e20\u0e32\u0e1e",
     "Title": "\u0e0a\u0e37\u0e48\u0e2d\u0e40\u0e23\u0e37\u0e48\u0e2d\u0e07",
-    "Insert image": "\u0e41\u0e17\u0e23\u0e01\u0e23\u0e39\u0e1b\u0e20\u0e32\u0e1e",
     "Drop image": "\u0e27\u0e32\u0e07\u0e20\u0e32\u0e1e",
     "or click": "\u0e2b\u0e23\u0e37\u0e2d\u0e04\u0e25\u0e34\u0e01\u0e17\u0e35\u0e48",
     "or": "\u0e2b\u0e23\u0e37\u0e2d",
